Function create active binding output mock to be used with renderUI mock
Source:R/mocks.R
activeOutput.RdFunction create active binding output mock to be used with renderUI mock
R/mocks.R
activeOutput.RdFunction create active binding output mock to be used with renderUI mock