Helper function to be used at the end of test files (useful if same session is used to run test and application e.g. RStudio)
Source:R/mocks.R
clearMocks.RdHelper function to be used at the end of test files (useful if same session is used to run test and application e.g. RStudio)