Skip to contents

create structure that can be used to signal error in applications

Usage

create.error(cond, meta = NULL)

Arguments

cond

- input from withCallingHandlers it should be unexpected error in app

meta

- addition extra data that should be added into meta property