helper function that can be used in exception handler to stop whole application
Source:R/exceptions.R
end.Rdhelper function that can be used in exception handler to stop whole application
R/exceptions.R
end.Rdhelper function that can be used in exception handler to stop whole application