Skip to contents

function allows to add global exception handler for all battery components

Usage

exceptions(handler = NULL, reset = FALSE, session = NULL)

Arguments

handler

- list of handlers

reset

- indicate if old handlers should be removed

session

- optional shiny session where to register the exception handler