Function check if obj is enviroment that is result of activeOutput function
Source:R/mocks.R
is.active.output.RdFunction check if obj is enviroment that is result of activeOutput function
R/mocks.R
is.active.output.RdFunction check if obj is enviroment that is result of activeOutput function