helper function that capture all signal messages into a vector it can be used in unit tests to check if the function sent proper messages
Source:R/exceptions.R
capture_signal_messages.Rdhelper function that capture all signal messages into a vector it can be used in unit tests to check if the function sent proper messages