create structure that can be used to signal error in applications
Source:R/exceptions.R
create.error.Rdcreate structure that can be used to signal error in applications
R/exceptions.R
create.error.Rdcreate structure that can be used to signal error in applications