function allows to add global exception handler for all battery components
Source:R/exceptions.R
exceptions.Rdfunction allows to add global exception handler for all battery components
R/exceptions.R
exceptions.Rdfunction allows to add global exception handler for all battery components