Mock for shiny::makeReactiveBinding to be injected into components limiation it can't be called after value is added to environment (it will work in components)
Source:R/mocks.R
makeReactiveBinding.RdMock for shiny::makeReactiveBinding to be injected into components limiation it can't be called after value is added to environment (it will work in components)